@@ -14,7 +14,7 @@ class BalancingPlayer(DjangoObjectType):
 
     class Meta:
         model = Player
-        fields = ["id", "inactive"]
+        fields = ["id", "inactive", "ready"]
 
     @staticmethod
     def resolve_name(obj: Player, info):
@@ -30,6 +30,7 @@ class BalancingTeam(DjangoObjectType):
     name = graphene.String()
     players = graphene.List(graphene.ID)
     session = graphene.String()
+    ready = graphene.Boolean()
 
     class Meta:
         model = models.Lobby
@@ -39,6 +40,10 @@ class BalancingTeam(DjangoObjectType):
     def resolve_name(obj: models.Lobby, info):
         return obj.name
 
+    @staticmethod
+    def resolve_ready(obj: models.Lobby, info):
+        return obj.ready
+
     @staticmethod
     def resolve_players(obj: models.Lobby, info):
         return [player.pk for player in obj.player_set.all()]
@@ -59,4 +64,4 @@ class Balancing(DjangoObjectType):
 
     @staticmethod
     def resolve_teams(obj, info):
-        return obj.lobby_set.all()
+        return obj.lobby_set.order_by("-date_created")
